@@ -9,16 +9,13 @@ features. But using template engines to build static websites is really useful.
 staticjinja is designed to be lightweight (under 500 lines of source code), and
 to be easy to use, learn, and extend, enabling you to focus on making your site.
 
-Documentation is available at http://staticjinja.readthedocs.org/en/latest/.
+Documentation is available at http://staticjinja.readthedocs.org.
 
 Please file bugs, view source code, and contribute at
 https://github.com/staticjinja/staticjinja/
 """
 
 # flake8: noqa
-
-from __future__ import absolute_import
-
 from .version import __version__, __version_info__
 
 from .reloader import Reloader
