@@ -1,13 +1,11 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 
-from __future__ import absolute_import
-
 import os
 
-import staticjinja
+from .staticjinja import Site
 
 if __name__ == "__main__":
     searchpath = os.path.join(os.getcwd(), 'templates')
-    site = staticjinja.make_site(searchpath=searchpath)
+    site = Site.make_site(searchpath=searchpath)
     site.render(use_reloader=True)
